summaryrefslogtreecommitdiffstats
path: root/Source/cmIfCommand.h
diff options
context:
space:
mode:
Diffstat (limited to 'Source/cmIfCommand.h')
-rw-r--r--Source/cmIfCommand.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/Source/cmIfCommand.h b/Source/cmIfCommand.h
index 4dcf884..af6dc7b 100644
--- a/Source/cmIfCommand.h
+++ b/Source/cmIfCommand.h
@@ -159,9 +159,10 @@ public:
}
// this is a shared function for both If and Else to determine if
// the arguments were valid, and if so, was the response true
static bool IsTrue(const std::vector<std::string> &args,
- bool &isValid, const cmMakefile *mf);
+ char** errorString, const cmMakefile *mf);
// Get a definition from the makefile. If it doesn't exist,
// return the original string.
@@ -159,9 +159,10 @@ public:
}
// this is a shared function for both If and Else to determine if
- // the arguments were valid, and if so, was the response true
+ // the arguments were valid, and if so, was the response true. If there is an
+ // error, the errorString will be set.
static bool IsTrue(const std::vector<std::string> &args,